@@ -65,7 +65,7 @@ $(function(){
 </header>
 <?php endif; ?>
 <div id="nav">
-<jdoc:include type="modules" name="user3" bootstyle="navbar-static-top" />
+<jdoc:include type="modules" name="user3" style="bootstyle" bootstyle="navbar-static-top" />
 <div class="hidden-xs"><jdoc:include type="modules" name="header-hide" style="none" /></div>
 </div>
 <div class="container">
