@@ -36,6 +36,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	private $buttonList;		// コンテンツ編集ボタン
 	// 表示制御
 	private $isSystemManageUser;	// システム運用可能ユーザかどうか
+	private $isCmdAccess;			// cmd付きアクセスかどうか
 	private $preview;				// プレビューモードかどうか
 	private $outputHead;			// ヘッダ出力するかどうか
 //	private $useWidgetTitle;		// ウィジェットタイトルを使用するかどうか
@@ -43,7 +44,8 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	private $useMultiBlog;			// マルチブログを使用するかどうか
 	private $isOutputComment;		// コメントを出力するかどうか
 	private $receiveComment;		// コメントを受け付けるかどうか
-
+	private $isAccessWithPageNo;	// ページ番号付きのアクセスかどうか(一覧の先頭かどうかを判断)
+	
 	// 表示項目
 	private $entryViewCount;// 記事表示数
 	private $entryViewOrder;// 記事表示順
@@ -54,6 +56,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	private $headTitle;		// METAタグタイトル
 	private $headDesc;		// METAタグ要約
 	private $headKeyword;	// METAタグキーワード
+	private $categoryDesc;	// カテゴリーの説明
 	private $addLib = array();		// 追加スクリプト
 	private $headScript;	// HTMLヘッダに埋め込むJavascript
 	private $viewMode;					// 表示モード
@@ -69,6 +72,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	private $itemTagLevel;			// 記事のタイトルタグレベル
 	private $showEntryAuthor;	// 投稿者を表示するかどうか
 	private $showEntryRegistDt;	// 投稿日時を表示するかどうか
+	private $showEntryViewCount;	// 閲覧数を表示するかどうか
 			
 	const LINK_PAGE_COUNT		= 5;			// リンクページ数
 	const ICON_SIZE = 32;		// アイコンのサイズ
@@ -129,6 +133,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 //		if (empty($this->startTitleTagLevel)) $this->startTitleTagLevel = blog_mainCommonDef::DEFAULT_TITLE_TAG_LEVEL;
 		$this->showEntryAuthor		= self::$_configArray[blog_mainCommonDef::CF_SHOW_ENTRY_AUTHOR];		// 投稿者を表示するかどうか
 		$this->showEntryRegistDt	= self::$_configArray[blog_mainCommonDef::CF_SHOW_ENTRY_REGIST_DT];		// 投稿日時を表示するかどうか
+		$this->showEntryViewCount	= self::$_configArray[blog_mainCommonDef::CF_SHOW_ENTRY_VIEW_COUNT];	// 閲覧数を表示するかどうか
 		$this->itemTagLevel = $this->getHTagLevel();			// 記事のタイトルタグレベル
 	}
 	/**
@@ -193,14 +198,17 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
 		$this->isOutputComment = false;// コメントを出力するかどうか
 		$this->isSystemManageUser = $this->gEnv->isSystemManageUser();	// システム運用可能ユーザかどうか
+		$this->isCmdAccess = $request->isCmdAccess();			// cmd付きアクセスかどうか
 		$this->pageTitle = '';		// 画面タイトル、パンくずリスト用タイトル
-		
+		$this->categoryDesc = '';	// カテゴリーの説明
+
 		// 入力値取得
 		$act = $request->trimValueOf('act');
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 		$this->pageNo = $request->trimIntValueOf('page', '1');				// ページ番号
 		$this->startDt = $request->trimValueOf('start');
 		$this->endDt = $request->trimValueOf('end');
+		$this->isAccessWithPageNo = ($request->trimValueOf('page') == '') ? false : true;		// ページ番号付きのアクセスかどうか(一覧の先頭かどうかを判断)
 		
 		// 管理者でプレビューモードのときは表示制限しない
 		$this->preview = false;
@@ -274,7 +282,8 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		}
 		
 		// ##### Joomla!新型テンプレートに記事データを設定 #####
-		$this->setJoomlaViewData($this->viewItemsData, count($this->viewItemsData)/*先頭(leading部)のコンテンツ数*/, 0/*カラム部(intro部)のコンテンツ数*/, 0/*カラム部(intro部)のカラム数*/);
+		$readmoreLabel = $topContent = self::$_configArray[blog_mainCommonDef::CF_READMORE_LABEL];// 「もっと読む」ボタンラベル
+		$this->setJoomlaViewData($this->viewItemsData, count($this->viewItemsData)/*先頭(leading部)のコンテンツ数*/, 0/*カラム部(intro部)のコンテンツ数*/, 0/*カラム部(intro部)のカラム数*/, $this->categoryDesc/*カテゴリーの説明*/, $readmoreLabel);
 		
 		// ##### 運用可能ユーザの場合は編集用ボタンを表示 #####
 		$this->createEditButton();
@@ -687,9 +696,14 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 				self::$_mainDb->getEntryItemsByCategory($this->entryViewCount, $this->pageNo, $this->now, $category, $this->_langId, $this->entryViewOrder, array($this, 'itemsLoop'), $this->_userId);
 			}
 
-			// タイトルの設定
+			// カテゴリータイトル、説明の設定
 			$ret = $this->categoryDb->getCategoryByCategoryId($category, $this->gEnv->getDefaultLanguage(), $row);
-			if ($ret) $this->title = str_replace('$1', $row['bc_name'], $this->titleList);
+			if ($ret){
+				$this->title = str_replace('$1', $row['bc_name'], $this->titleList);
+				
+				// 一覧の先頭の場合は、カテゴリーの説明を付加
+				if (!$this->isAccessWithPageNo) $this->categoryDesc = $row['bc_html'];// ページ番号付きのアクセスかどうか
+			}
 			
 			// ブログ記事データがないときはデータなしメッセージ追加
 			if ($this->isExistsViewData){
@@ -934,10 +948,12 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	function itemsLoop($index, $fetchedRow)
 	{
 		// 参照ビューカウントを更新
-		if (!$this->isSystemManageUser){		// システム運用者以上の場合はカウントしない
+		if (!$this->isSystemManageUser &&		// システム運用者以上の場合はカウントしない
+			!$this->isCmdAccess){				// cmd付きアクセスでない
 			$this->gInstance->getAnalyzeManager()->updateContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $fetchedRow['be_serial'], $this->currentDay, $this->currentHour);
 		}
 
+		$serial = $fetchedRow['be_serial'];		// シリアル番号
 		$entryId = $fetchedRow['be_id'];// 記事ID
 		$title = $fetchedRow['be_name'];// タイトル
 		$date = $fetchedRow['be_regist_dt'];// 登録日時
@@ -1120,6 +1136,8 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 			$contentInfo[M3_TAG_MACRO_CONTENT_REGIST_DT] = '';		// コンテンツ置換キー(登録日時)
 			$contentInfo[M3_TAG_MACRO_CONTENT_DATE] = '';		// コンテンツ置換キー(登録日)
 			$contentInfo[M3_TAG_MACRO_CONTENT_TIME] = '';		// コンテンツ置換キー(登録時)
+			if ($this->showEntryViewCount) $viewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $serial);
+			$contentInfo[M3_TAG_MACRO_CONTENT_VIEW_COUNT] = '';			// コンテンツ置換キー(閲覧数)
 		} else {
 			if ($this->showEntryAuthor){		// 投稿者
 				$contentInfo[M3_TAG_MACRO_CONTENT_AUTHOR] = $author;			// コンテンツ置換キー(著者)
@@ -1135,6 +1153,12 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 				$contentInfo[M3_TAG_MACRO_CONTENT_DATE] = '';		// コンテンツ置換キー(登録日)
 				$contentInfo[M3_TAG_MACRO_CONTENT_TIME] = '';		// コンテンツ置換キー(登録時)
 			}
+			if ($this->showEntryViewCount){		// 閲覧数を表示するかどうか
+				$viewCount = $this->gInstance->getAnalyzeManager()->getTotalContentViewCount(blog_mainCommonDef::VIEW_CONTENT_TYPE, $serial);
+				$contentInfo[M3_TAG_MACRO_CONTENT_VIEW_COUNT] = $viewCount;			// コンテンツ置換キー(閲覧数)
+			} else {
+				$contentInfo[M3_TAG_MACRO_CONTENT_VIEW_COUNT] = '';			// コンテンツ置換キー(閲覧数)
+			}
 		}
 		
 		// HTMLを出力(出力内容は特にエラーチェックしない)
@@ -1209,6 +1233,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		// 以下は表示する項目のみ値を設定する
 		if ($this->showEntryAuthor) $viewItem->author		= $author;		// 投稿者
 		if ($this->showEntryRegistDt) $viewItem->published	= $date;		// 投稿日時
+		if ($this->showEntryViewCount) $viewItem->hits		= $viewCount;	// 閲覧数
 		$this->viewItemsData[] = $viewItem;			// Joomla!ビュー用データ
 		return true;
 	}
@@ -1357,7 +1382,9 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 	 */
 	function addPageHeadingContent($msgHtml)
 	{
-		// ### Joomla!新型テンプレート用データ作成 ###
+		// メッセージをカテゴリー説明の前に追加
+		$this->categoryDesc = '<div>' . $msgHtml . '</div>' . $this->categoryDesc;
+/*		// ### Joomla!新型テンプレート用データ作成 ###
 		$viewItem = new stdClass;
 		$viewItem->introtext	= $msgHtml;	// コンテンツ内容(Joomla!2.5以降テンプレート用)
 		$viewItem->text			= $msgHtml;	// コンテンツ内容(Joomla!1.5テンプレート用)
@@ -1365,6 +1392,7 @@ class blog_mainTopWidgetContainer extends blog_mainBaseWidgetContainer
 		
 		// 既存のビューデータの先頭に追加
 		$this->viewItemsData = array_merge(array($viewItem), $this->viewItemsData);
+		*/
 	}
 	/**
 	 * 記事編集用のボタンを作成
